import * as t from 'drizzle-orm/pg-core';
import { timestamps } from '../util';
import { competitions } from './competitions';
import { relations } from 'drizzle-orm';
import { fields } from './fields';
import { schedulingModes } from './schedulingmodes';

export const status = t.pgEnum('match_status', ['pending', 'running', 'finished', 'cancelled']);

export const matches = t.pgTable('match', {
	id: t.serial('id').primaryKey(),
	competition_id: t.integer('competition_id').notNull(),
	scheduling_mode_id: t.integer('scheduling_mode_id').notNull(),
	field_id: t.integer('field_id').notNull(),
	team1: t.text('team1').notNull(),
	team2: t.text('team2').notNull(),
	start_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	end_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	score1: t.integer('score1').notNull(),
	score2: t.integer('score2').notNull(),
	status: status('status').notNull(),
	match_number: t.integer('match_number').notNull(),
	...timestamps
});

export const matchRelations = relations(matches, ({ one }) => ({
	competition: one(competitions, {
		fields: [matches.competition_id],
		references: [competitions.id]
	}),
	field: one(fields, {
		fields: [matches.field_id],
		references: [fields.id]
	}),
	scheduling_mode: one(schedulingModes, {
		fields: [matches.scheduling_mode_id],
		references: [schedulingModes.id]
	})
}));

export type Match = typeof matches.$inferSelect;
